from django.contrib.admin.views.decorators import staff_member_required
from django.http import HttpResponseRedirect
from django.shortcuts import get_object_or_404, render
from django.urls import reverse

from .forms import FileUploadForm
from .models import FileBrowserFile


@staff_member_required
def filebrowser(request, file_type):
    """ Trigger view for filebrowser """
    template = 'filebrowser.html'
    upload_form = FileUploadForm()
    uploaded_file = None
    upload_tab_active = False
    is_images_dialog = (file_type == 'img')
    is_documents_dialog = (file_type == 'doc')
    
    files = FileBrowserFile.objects.filter(file_type=file_type)
    
    if request.POST:
        upload_form = FileUploadForm(request.POST, request.FILES)
        upload_tab_active = True
        
        if upload_form.is_valid():
            uploaded_file = upload_form.save(commit=False)
            uploaded_file.file_type = file_type
            uploaded_file.save()
    
    data = {
        'files': files,
        'upload_form': upload_form,
        'uploaded_file': uploaded_file,
        'upload_tab_active': upload_tab_active,
        'is_images_dialog': is_images_dialog,
        'is_documents_dialog': is_documents_dialog
    }
    
    return render(request, template, data)


@staff_member_required
def filebrowser_remove_file(request, item_id, file_type):
    fobj = get_object_or_404(FileBrowserFile, file_type=file_type, id=item_id)
    fobj.delete()
    
    if file_type == 'doc':
        return HttpResponseRedirect(reverse('tinymce-filebrowser-documents'))
    
    return HttpResponseRedirect(reverse('tinymce-filebrowser-images'))



from django.db import models
from django.utils.translation import ugettext as _


class FileBrowserFile(models.Model):
    """ Uploaded file model """
    FILE_TYPES = (
        ('img', _('Image')),
        ('doc', _('Document')),
    )
    
    file_type = models.CharField(max_length=3, choices=FILE_TYPES)
    uploaded_file = models.FileField(
        upload_to='tinymce_filebrowser/%Y/%m/%d',
        verbose_name=_('File / Image')
    )
    create_date = models.DateTimeField(
        auto_now_add=True, verbose_name=_('Create date')
    )
    
    def __unicode__(self):
        return u'%s' % self.uploaded_file.name



from django import forms

from .models import FileBrowserFile


class FileUploadForm(forms.ModelForm):
    """ File/Image Upload form """
    class Meta:
        model = FileBrowserFile
        fields = ('uploaded_file',)



# Generated by Django 3.2.2 on 2021-05-10 12:44

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='FileBrowserFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file_type', models.CharField(choices=[('img', 'Изображение'), ('doc', 'Документ')], max_length=3)),
                ('uploaded_file', models.FileField(upload_to='tinymce_filebrowser/%Y/%m/%d', verbose_name='File / Image')),
                ('create_date', models.DateTimeField(auto_now_add=True, verbose_name='Create date')),
            ],
        ),
    ]



try:
    from django.conf.urls.defaults import url
except ImportError:
    from django.conf.urls import url

from . import views

urlpatterns = [
    url(r'^image/$',
        views.filebrowser,
        {'file_type': 'img'},
        name='tinymce-filebrowser-images'
        ),
    url(r'^file/$',
        views.filebrowser,
        {'file_type': 'doc'},
        name='tinymce-filebrowser-documents'
        ),
    url(r'^image/remove/(?P<item_id>\d+)/$',
        views.filebrowser_remove_file,
        {'file_type': 'img'},
        name='tinymce-filebrowser-remove-image'
        ),
    url(r'^file/remove/(?P<item_id>\d+)/$',
        views.filebrowser_remove_file,
        {'file_type': 'doc'},
        name='tinymce-filebrowser-remove-document'
        )
]



"""
tinymce-filebrowser-django
-----------------
Simple django-based file uploader and viewer for TinyMCE
"""
from setuptools import setup, find_packages


setup(
    name='tinymce-filebrowser-django',
    version='1.0.3',
    url='https://github.com/ituxka/tinymce-filebrowser-django',
    license='MIT License',
    author='Nikita Sologub',
    author_email='ituxka@gmail.com',
    description='Django-based file uploader and viewer for TinyMCE',
    keywords="django tinymce fileupload",
    long_description='Django-based file uploader and viewer for TinyMCE',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=[
        'django-tinymce'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)